@@ -17,16 +17,7 @@
 #include "transfer.h"
 #include "audioconverter.h"
 #include "definitions.h"
-#include "resources.h"
-#include "resourcesrequest.h"
 #include "settings.h"
-#include "vimeo.h"
-#include <qdailymotion/resourcesrequest.h>
-#include <qdailymotion/streamsrequest.h>
-#include <qvimeo/resourcesrequest.h>
-#include <qvimeo/streamsrequest.h>
-#include <qyoutube/streamsrequest.h>
-#include <qyoutube/subtitlesrequest.h>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QFile>
@@ -35,9 +26,6 @@
 #include <TransferUI/Client>
 #include <TransferUI/Transfer>
 #endif
-#if QT_VERSION >= 0x050000
-#include <QUrlQuery>
-#endif
 #ifdef CUTETUBE_DEBUG
 #include <QDebug>
 #endif
@@ -45,16 +33,12 @@
 #ifdef MEEGO_EDITION_HARMATTAN
 TransferUI::Client* Transfer::tuiClient = 0;
 #endif
+#ifdef SYMBIAN_OS
+static const qint64 BUFFER_SIZE = 1024 * 512;
+#endif
 
 Transfer::Transfer(QObject *parent) :
     QObject(parent),
-    m_dailymotionStreamsRequest(0),
-    m_vimeoStreamsRequest(0),
-    m_youtubeStreamsRequest(0),
-    m_dailymotionSubtitlesRequest(0),
-    m_vimeoSubtitlesRequest(0),
-    m_youtubeSubtitlesRequest(0),
-    m_streamsRequest(0),
     m_audioConverter(0),
     m_nam(0),
     m_reply(0),
@@ -525,6 +509,7 @@ void Transfer::start() {
         break;
     }
     
+    setStatus(Connecting);
     listStreams();
 }
 
@@ -533,6 +518,7 @@ void Transfer::pause() {
     case Paused:
     case Canceled:
     case Completed:
+    case Connecting:
     case Converting:
         return;
     default:
@@ -569,58 +555,6 @@ void Transfer::cancel() {
     }
 }
 
-void Transfer::listStreams() {
-    if (service() == Resources::YOUTUBE) {
-        if (!m_youtubeStreamsRequest) {
-            m_youtubeStreamsRequest = new QYouTube::StreamsRequest(this);
-            connect(m_youtubeStreamsRequest, SIGNAL(finished()), this, SLOT(onStreamsRequestFinished()));
-        }
-        
-        setStatus(Connecting);
-        m_youtubeStreamsRequest->list(resourceId());
-    }
-    else if (service() == Resources::DAILYMOTION) {
-        if (!m_dailymotionStreamsRequest) {
-            m_dailymotionStreamsRequest = new QDailymotion::StreamsRequest(this);
-            connect(m_dailymotionStreamsRequest, SIGNAL(finished()), this, SLOT(onStreamsRequestFinished()));
-        }
-        
-        setStatus(Connecting);
-        m_dailymotionStreamsRequest->list(resourceId());
-    }
-    else if (service() == Resources::VIMEO) {
-        if (!m_vimeoStreamsRequest) {
-            m_vimeoStreamsRequest = new QVimeo::StreamsRequest(this);
-            connect(m_vimeoStreamsRequest, SIGNAL(finished()), this, SLOT(onStreamsRequestFinished()));
-        }
-        
-        setStatus(Connecting);
-        m_vimeoStreamsRequest->list(resourceId());
-    }
-    else {
-        if (!m_streamsRequest) {
-            m_streamsRequest = new ResourcesRequest(this);
-            m_streamsRequest->setService(service());
-            connect(m_streamsRequest, SIGNAL(finished()), this, SLOT(onStreamsRequestFinished()));
-        }
-        
-        setStatus(Connecting);
-        m_streamsRequest->list(Resources::STREAM, resourceId());
-    }
-}
-
-QUrl Transfer::getStreamUrl(const QVariantList &list) const {
-    foreach (QVariant v, list) {
-        QVariantMap stream = v.toMap();
-        
-        if (stream.value("id") == streamId()) {
-            return stream.value("url").toUrl();
-        }
-    }
-    
-    return QUrl();
-}
-
 void Transfer::startDownload(const QUrl &u) {
     QDir().mkpath(downloadPath());
     
@@ -688,66 +622,6 @@ void Transfer::followRedirect(const QUrl &u) {
     connect(m_reply, SIGNAL(finished()), this, SLOT(onReplyFinished()));
 }
 
-void Transfer::listSubtitles() {
-    if (service() == Resources::YOUTUBE) {
-        if (!m_youtubeSubtitlesRequest) {
-            m_youtubeSubtitlesRequest = new QYouTube::SubtitlesRequest(this);
-            connect(m_youtubeSubtitlesRequest, SIGNAL(finished()), this, SLOT(onSubtitlesRequestFinished()));
-        }
-        
-        m_youtubeSubtitlesRequest->list(resourceId());
-    }
-    else if (service() == Resources::DAILYMOTION) {
-        if (!m_dailymotionSubtitlesRequest) {
-            m_dailymotionSubtitlesRequest = new QDailymotion::ResourcesRequest(this);
-            connect(m_dailymotionSubtitlesRequest, SIGNAL(finished()), this, SLOT(onSubtitlesRequestFinished()));
-        }
-        
-        m_dailymotionSubtitlesRequest->list("/video/" + resourceId() + "/subtitles");
-    }
-    else if (service() == Resources::VIMEO) {
-        if (!m_vimeoSubtitlesRequest) {
-            m_vimeoSubtitlesRequest = new QVimeo::ResourcesRequest(this);
-            m_vimeoSubtitlesRequest->setClientId(Vimeo::instance()->clientId());
-            m_vimeoSubtitlesRequest->setClientSecret(Vimeo::instance()->clientSecret());
-            m_vimeoSubtitlesRequest->setAccessToken(Vimeo::instance()->accessToken());
-            connect(m_vimeoSubtitlesRequest, SIGNAL(finished()), this, SLOT(onSubtitlesRequestFinished()));
-        }
-        
-        m_vimeoSubtitlesRequest->list("/videos/" + resourceId() + "/texttracks");
-    }
-    else {
-        setErrorString(tr("Service type unknown"));
-        setStatus(Failed);
-    }
-}
-
-QUrl Transfer::getSubtitlesUrl(const QVariantList &list) const {
-    QString val = service() == Resources::YOUTUBE ? QString("translatedLanguage") : QString("name");
-    
-    foreach (QVariant v, list) {
-        QVariantMap sub = v.toMap();
-        
-        if (sub.value(val) == subtitlesLanguage()) {
-            QUrl u = sub.value("url").toUrl();
-            
-            if (service() == Resources::YOUTUBE) {
-#if QT_VERSION >= 0x050000
-                QUrlQuery query(u);
-                query.addQueryItem("fmt", "srt");
-                u.setQuery(query);
-#else
-                u.addQueryItem("fmt", "srt");
-#endif
-            }
-            
-            return u;
-        }
-    }
-    
-    return QUrl();
-}
-
 void Transfer::startSubtitlesDownload(const QUrl &u) {    
     if (!m_nam) {
         m_nam = new QNetworkAccessManager(this);
@@ -837,8 +711,16 @@ void Transfer::onReplyMetaDataChanged() {
 
 void Transfer::onReplyReadyRead() {
     m_bytesTransferred += m_reply->bytesAvailable();
+#ifdef SYMBIAN_OS
+    m_buffer += m_reply->readAll();
+
+    if (m_buffer.size() >= BUFFER_SIZE) {
+        m_file.write(m_buffer);
+        m_buffer.clear();
+    }
+#else
     m_file.write(m_reply->readAll());
-    
+#endif
     if (m_size > 0) {
         setProgress(m_bytesTransferred * 100 / m_size);
     }
@@ -852,14 +734,19 @@ void Transfer::onReplyFinished() {
     if (redirect.isNull()) {
         redirect = m_reply->header(QNetworkRequest::LocationHeader);        
     }
-    
+#ifdef SYMBIAN_OS
+    if (!m_buffer.isEmpty()) {
+        m_file.write(m_buffer);
+        m_buffer.clear();
+    }
+#endif
     m_file.close();
     m_reply->deleteLater();
     m_reply = 0;
     
     if (!redirect.isNull()) {
         if (m_redirects < MAX_REDIRECTS) {
-            followRedirect(redirect.toUrl());
+            followRedirect(redirect.toString());
         }
         else {
             setErrorString(tr("Maximum redirects reached"));
@@ -902,92 +789,6 @@ void Transfer::onReplyFinished() {
     }
 }
 
-void Transfer::onStreamsRequestFinished() {
-    if (service() == Resources::YOUTUBE) {
-        if (m_youtubeStreamsRequest) {
-            QUrl u = getStreamUrl(m_youtubeStreamsRequest->result().toList());
-            
-            if (!u.isEmpty()) {
-                startDownload(u);
-                return;
-            }
-        }
-    }
-    else if (service() == Resources::DAILYMOTION) {
-        if (m_dailymotionStreamsRequest) {
-            QUrl u = getStreamUrl(m_dailymotionStreamsRequest->result().toList());
-            
-            if (!u.isEmpty()) {
-                startDownload(u);
-                return;
-            }
-        }
-    }
-    else if (service() == Resources::VIMEO) {
-        if (m_vimeoStreamsRequest) {
-            QUrl u = getStreamUrl(m_vimeoStreamsRequest->result().toList());
-            
-            if (!u.isEmpty()) {
-                startDownload(u);
-                return;
-            }
-        }
-    }
-    else if (m_streamsRequest) {
-        QUrl u = getStreamUrl(m_streamsRequest->result().toMap().value("items").toList());
-        
-        if (!u.isEmpty()) {
-            startDownload(u);
-            return;
-        }
-    }
-    
-    setErrorString(tr("No stream URL found"));
-    setStatus(Failed);
-}
-
-void Transfer::onSubtitlesRequestFinished() {
-    if (service() == Resources::YOUTUBE) {
-        if (m_youtubeSubtitlesRequest) {
-            QUrl u = getSubtitlesUrl(m_youtubeSubtitlesRequest->result().toList());
-            
-            if (!u.isEmpty()) {
-                startSubtitlesDownload(u);
-                return;
-            }
-        }
-    }
-    else if (service() == Resources::DAILYMOTION) {
-        if (m_dailymotionSubtitlesRequest) {
-            QUrl u = getSubtitlesUrl(m_dailymotionSubtitlesRequest->result().toMap().value("list").toList());
-            
-            if (!u.isEmpty()) {
-                startSubtitlesDownload(u);
-                return;
-            }
-        }
-    }
-    else if (service() == Resources::VIMEO) {
-        if (m_vimeoSubtitlesRequest) {
-            QUrl u = getSubtitlesUrl(m_vimeoSubtitlesRequest->result().toMap().value("items").toList());
-            
-            if (!u.isEmpty()) {
-                startSubtitlesDownload(u);
-                return;
-            }
-        }
-    }
-#ifdef CUTETUBE_DEBUG
-    qDebug() << "Transfer::onSubtitlesRequestFinished: No subtitles found";
-#endif
-    if (convertToAudio()) {
-        startAudioConversion();
-    }
-    else {
-        moveDownloadedFiles();
-    }
-}
-
 void Transfer::onSubtitlesReplyFinished() {
     switch (m_reply->error()) {
     case QNetworkReply::NoError:
