@@ -22,8 +22,8 @@
 #include "dailymotionvideomodel.h"
 
 class DailymotionUser;
-class DailymotionVideoDelegate;
-class DailymotionCommentDelegate;
+class VideoDelegate;
+class CommentDelegate;
 class Image;
 class ImageCache;
 class ListView;
@@ -100,8 +100,8 @@ private:
     Image *m_avatar;
     ListView *m_relatedView;
     ListView *m_commentView;
-    DailymotionVideoDelegate *m_relatedDelegate;
-    DailymotionCommentDelegate *m_commentDelegate;
+    VideoDelegate *m_relatedDelegate;
+    CommentDelegate *m_commentDelegate;
     QScrollArea *m_scrollArea;
     QTabBar *m_tabBar;
     QStackedWidget *m_stack;
