@@ -23,8 +23,8 @@
 #include "pluginvideowindow.h"
 #include "settings.h"
 #include "videodelegate.h"
+#include "videolauncher.h"
 #include "videoplaybackwindow.h"
-#include "videoplayer.h"
 #include <QLabel>
 #include <QActionGroup>
 #include <QMessageBox>
@@ -156,7 +156,7 @@ void PluginVideosWindow::playVideo(const QModelIndex &index) {
         QString url = index.data(PluginVideoModel::StreamUrlRole).toString();
         
         if (!url.isEmpty()) {
-            VideoPlayer::playVideo(url);
+            VideoLauncher::playVideo(url);
         }
         else {
             QString id = index.data(PluginVideoModel::IdRole).toString();
