@@ -22,8 +22,8 @@
 #include "pluginvideomodel.h"
 
 class PluginUser;
-class PluginVideoDelegate;
-class PluginCommentDelegate;
+class VideoDelegate;
+class CommentDelegate;
 class Image;
 class ImageCache;
 class ListView;
@@ -94,8 +94,8 @@ private:
     Image *m_avatar;
     ListView *m_relatedView;
     ListView *m_commentView;
-    PluginVideoDelegate *m_relatedDelegate;
-    PluginCommentDelegate *m_commentDelegate;
+    VideoDelegate *m_relatedDelegate;
+    CommentDelegate *m_commentDelegate;
     QScrollArea *m_scrollArea;
     QTabBar *m_tabBar;
     QStackedWidget *m_stack;
