@@ -39,10 +39,11 @@ public Q_SLOTS:
     void showResource(const QString &type, const QString &id);
     
 private:
-    void showPlaylists();
+    void showCategories(const QString &id);
+    void showPlaylists(const QString &id);
     void showSearchDialog();
-    void showUsers();
-    void showVideos();
+    void showUsers(const QString &id);
+    void showVideos(const QString &id);
     
 private Q_SLOTS:
     void onItemActivated(const QModelIndex &index);
