@@ -17,6 +17,7 @@
 #ifndef RESOURCESPLUGINS_H
 #define RESOURCESPLUGINS_H
 
+#include "resources.h"
 #include <QObject>
 #include <QMap>
 #include <QStringList>
@@ -26,9 +27,9 @@ struct ResourcesPlugin {
     QString name;
     QString command;
     QString settings;
-    QStringList supportedListResources;
-    QStringList supportedSearchResources;
-    QRegExp urlRegExp;
+    QMultiMap<QString, ListResource> listResources;
+    QMultiMap<QString, SearchResource> searchResources;
+    QMap<QString, QRegExp> regExps;
 };
 
 class ResourcesPlugins : public QObject
@@ -42,13 +43,12 @@ public:
     static ResourcesPlugins* instance();
     
     ResourcesPlugin getPluginFromName(const QString &name) const;
-    ResourcesPlugin getPluginFromUrl(const QString &url) const;
     
     QList<ResourcesPlugin> plugins() const;
     
     QStringList pluginNames() const;
     
-    Q_INVOKABLE bool resourceTypeIsSupported(const QString &name, const QString &resourceType,
+    Q_INVOKABLE bool resourceTypeIsSupported(const QString &pluginName, const QString &resourceType,
                                              const QString &method = QString("list")) const;
     
 public Q_SLOTS:
